PyXMake Developer Guide: PyXMake.VTL.stm_make.LongTest Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Attributes | Protected Member Functions | List of all members
PyXMake.VTL.stm_make.LongTest Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.LongTest:

## Public Attributes
str | out = "xml":
Public Attributes inherited from PyXMake.VTL.stm_make._BaseTest
str | command = "py.test"
| out = None
| covout = None
| verbose = self.distribution.verbose
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Protected Member Functions
| _create_command (self)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _run_command (self, command)
| _perform_post_actions (self)

## Additional Inherited Members
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseTest
| initialize_options (self)
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)
Static Public Attributes inherited from PyXMake.VTL.stm_make._BaseTest
str | description = "Runs all unit tests using py.test."
list | user_options
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()

## Detailed Description

    Runs all unit tests.

Definition at line 1071 of file stm_make.py.

## Member Function Documentation

## ◆ _create_command()

PyXMake.VTL.stm_make.LongTest._create_command | ( |  | self | ) |
| protected

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 1075 of file stm_make.py.

## Member Data Documentation

## ◆ out

str PyXMake.VTL.stm_make.LongTest.out = "xml":

Definition at line 1077 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py